@@ -36,6 +36,7 @@ __all__ = (
     "ScheduleEntryTypeType",
     "TypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -335,3 +336,11 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "get_channel_schedule",
+    "list_alerts",
+    "list_channels",
+    "list_playback_configurations",
+    "list_source_locations",
+    "list_vod_sources",
+]
